==> identity-apps-1.0.117-source-release.zip: identity-apps-1.0.117/CREDITS.md <==
# Icon Authors

| Icon             |  Author |  Link |
:-------------------------:|:-------------------------:|:-------------------------:
![dashboard](modules/theme/src/themes/default/assets/images/icons/dashboard-icon.svg) | Icon made by Freepik from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/speedometer_2204#term=dashboard&page=1&position=13)
![user](modules/theme/src/themes/default/assets/images/icons/user-icon.svg) | Icon made by Freepik from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/user_747376#term=user&page=1&position=4)
![controls](modules/theme/src/themes/default/assets/images/icons/controls-icon.svg) | Icon made by Smashicons from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/controls_149269#term=settings&page=1&position=28)
![lock](modules/theme/src/themes/default/assets/images/icons/lock-icon.svg) | Icon made by Those Icons from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/lock_481195#term=security&page=1&position=38)
![tick](modules/theme/src/themes/default/assets/images/icons/tick-circle-icon.svg) | Icon made by Google from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/tick-inside-circle_61222#term=tick&page=1&position=6)
![monitor](modules/theme/src/themes/default/assets/images/icons/monitor-icon.svg) | Icon made by Pixel perfect from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/hand-shake_493808#term=shake%20hands&page=1&position=2)
![sms](modules/theme/src/themes/default/assets/images/icons/sms-icon.svg) | Icon made by Alfredo Hernandez from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/speech-bubble_156974#term=sms&page=1&position=25)
![fingerprint](modules/theme/src/themes/default/assets/images/icons/fingerprint.svg) | Icon made by Smashicons from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/fingerprint_1230995#term=fingerprint%20scanner&page=1&position=22)
![package](modules/theme/src/themes/default/assets/images/icons/package.svg) | Icon made by Freepik from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/package-cube-box-for-delivery_45806#term=package&page=1&position=50)
![tools](modules/theme/src/themes/default/assets/images/icons/tools-icon.svg) | Icon made by monkik from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/customer-support_1086581#term=tools&page=1&position=33)
![magnifier](modules/theme/src/themes/default/assets/images/icons/blocked-magnifier-icon.svg) | Icon made by Freepik from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/not-found_1178479?term=page%20not%20found&page=1&position=1)
![box](modules/theme/src/themes/default/assets/images/icons/box-icon.svg) | Icon made by Freepik from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/box_1380641?term=empty%20box&page=1&position=1)
![close](modules/theme/src/themes/default/assets/images/icons/close-icon.svg) | Icon made by Smashicons from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/close_402715)
![consent](modules/theme/src/themes/default/assets/images/icons/consent-icon.svg) | Icon made by Wichai.wi from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/gdpr_1355236?term=gdpr&page=1&position=3)
![forbidden](modules/theme/src/themes/default/assets/images/icons/forbidden-icon.svg) | Icon made by Freepik from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/prohibition-symbol_12572?term=not%20permitted&page=1&position=2)
![plug](modules/theme/src/themes/default/assets/images/icons/plug-icon.svg) | Icon made by prettycons from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/plug_978016?term=plug&page=1&position=20)
![drag](modules/theme/src/themes/default/assets/images/icons/drag-icon.svg) | Icon made by Pixel Perfect from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/drag_624828?term=drag&page=1&position=2)

# Illustration Owners

|Illustration|Author|Link|
:-:|:-:|:-:|
|![QRCodeScan](modules/theme/src/themes/default/assets/images/illustrations/qrcode-scan.svg)|Invitation Vectors by Vecteezy|[Link](https://www.vecteezy.com/free-vector/invitation)|
|![EnterVerificationCode](modules/theme/src/themes/default/assets/images/illustrations/enter-verification-code.svg)|From [Wikimedia Commons](https://commons.wikimedia.org/wiki/Main_Page) by [Videoplasty.com](https://videoplasty.com/)|[Link](https://commons.wikimedia.org/wiki/File:Laptop_Typing_Scene_Vector.svg)|

==> identity-apps-1.0.217-source-release.zip: identity-apps-1.0.217/CREDITS.md <==
# Icon Authors

| Icon             |  Author |  Link |
:-------------------------:|:-------------------------:|:-------------------------:
![dashboard](modules/theme/src/themes/default/assets/images/icons/dashboard-icon.svg) | Icon made by Freepik from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/speedometer_2204#term=dashboard&page=1&position=13)
![user](modules/theme/src/themes/default/assets/images/icons/user-icon.svg) | Icon made by Freepik from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/user_747376#term=user&page=1&position=4)
![controls](modules/theme/src/themes/default/assets/images/icons/controls-icon.svg) | Icon made by Smashicons from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/controls_149269#term=settings&page=1&position=28)
![lock](modules/theme/src/themes/default/assets/images/icons/lock-icon.svg) | Icon made by Those Icons from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/lock_481195#term=security&page=1&position=38)
![tick](modules/theme/src/themes/default/assets/images/icons/tick-circle-icon.svg) | Icon made by Google from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/tick-inside-circle_61222#term=tick&page=1&position=6)
![monitor](modules/theme/src/themes/default/assets/images/icons/monitor-icon.svg) | Icon made by Pixel perfect from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/hand-shake_493808#term=shake%20hands&page=1&position=2)
![sms](modules/theme/src/themes/default/assets/images/icons/sms-icon.svg) | Icon made by Alfredo Hernandez from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/speech-bubble_156974#term=sms&page=1&position=25)
![fingerprint](modules/theme/src/themes/default/assets/images/icons/fingerprint.svg) | Icon made by Smashicons from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/fingerprint_1230995#term=fingerprint%20scanner&page=1&position=22)
![package](modules/theme/src/themes/default/assets/images/icons/package.svg) | Icon made by Freepik from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/package-cube-box-for-delivery_45806#term=package&page=1&position=50)
![tools](modules/theme/src/themes/default/assets/images/icons/tools-icon.svg) | Icon made by monkik from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/customer-support_1086581#term=tools&page=1&position=33)
![magnifier](modules/theme/src/themes/default/assets/images/icons/blocked-magnifier-icon.svg) | Icon made by Freepik from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/not-found_1178479?term=page%20not%20found&page=1&position=1)
![box](modules/theme/src/themes/default/assets/images/icons/box-icon.svg) | Icon made by Freepik from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/box_1380641?term=empty%20box&page=1&position=1)
![close](modules/theme/src/themes/default/assets/images/icons/close-icon.svg) | Icon made by Smashicons from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/close_402715)
![consent](modules/theme/src/themes/default/assets/images/icons/consent-icon.svg) | Icon made by Wichai.wi from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/gdpr_1355236?term=gdpr&page=1&position=3)
![forbidden](modules/theme/src/themes/default/assets/images/icons/forbidden-icon.svg) | Icon made by Freepik from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/prohibition-symbol_12572?term=not%20permitted&page=1&position=2)
![plug](modules/theme/src/themes/default/assets/images/icons/plug-icon.svg) | Icon made by prettycons from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/plug_978016?term=plug&page=1&position=20)
![drag](modules/theme/src/themes/default/assets/images/icons/drag-icon.svg) | Icon made by Pixel Perfect from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/drag_624828?term=drag&page=1&position=2)
![database](modules/theme/src/themes/default/assets/images/icons/database-icon.svg) | Icon made by catkuro from www.flaticon.com | [Link](https://www.flaticon.com/free-icon/database_1980250?term=database&page=1&position=4)

# Illustration Owners

|Illustration|Author|Link|
:-:|:-:|:-:|
|![QRCodeScan](modules/theme/src/themes/default/assets/images/illustrations/qrcode-scan.svg)|Invitation Vectors by Vecteezy|[Link](https://www.vecteezy.com/free-vector/invitation)|
|![EnterVerificationCode](modules/theme/src/themes/default/assets/images/illustrations/enter-verification-code.svg)|From [Wikimedia Commons](https://commons.wikimedia.org/wiki/Main_Page) by [Videoplasty.com](https://videoplasty.com/)|[Link](https://commons.wikimedia.org/wiki/File:Laptop_Typing_Scene_Vector.svg)|
